Sr No | Judgment/Order | Case Details | Court | Judge(s) | Decision Date | Download
--- | --- | --- | --- | --- | --- | ---
1 | Judgment | ABC Industries vs Union of India WP(C)/12345/2024 CNR NumberDLHC010012342024 Date of Registration05-01-2024 Date of Decision15-02-2024 Disposal NatureAllowed | Delhi High Court | Division Bench | 15-02-2024 | Download PDF
2 | Judgment | State vs XYZ Enterprises CRL.A./567/2023 | Delhi High Court | Single Bench | 20-01-2024 | Download PDF

Showing 1 to 2 of 45 entries Next